(this["webpackJsonpst-tokenization-vis-component"]=this["webpackJsonpst-tokenization-vis-component"]||[]).push([[0],{35:function(e,a,t){e.exports=t(46)},46:function(e,a,t){"use strict";t.r(a);var n=t(4),r=t.n(n),l=t(32),c=t.n(l),m=t(0),u=t(1),i=t(2),o=t(3),s=t(30),E=t(20),p=t(28),d=t(19),k=t(22),f=t(21),g=t(26),h=t(34),b=function(e){Object(i.a)(t,e);var a=Object(o.a)(t);function t(){var e;Object(u.a)(this,t);for(var n=arguments.length,l=new Array(n),c=0;c<n;c++)l[c]=arguments[c];return(e=a.call.apply(a,[this].concat(l))).render=function(){var a=e.props.args.data,t=e.props.args.isToken,n=(e.props.theme,Object.keys(a));return t?r.a.createElement(k.a,{text:"dark"},r.a.createElement(k.a.Header,null,r.a.createElement("h4",null,"Tokenization")),r.a.createElement(f.a,{variant:"flush"},n.map((function(e){return r.a.createElement(f.a.Item,{key:e},r.a.createElement("h5",null,e," :"),Object.keys(a[e]).map((function(t){return r.a.createElement(p.a,{key:t},r.a.createElement(d.a,{md:1},r.a.createElement(E.a,{variant:"dark",className:"m-1",disabled:!0},t,". ",r.a.createElement(r.a.Fragment,null),r.a.createElement(r.a.Fragment,null),r.a.createElement(g.a,null,a[e][t].length))),r.a.createElement(d.a,null,a[e][t].map((function(e,a){return r.a.createElement(E.a,{variant:"info",className:"m-1",key:a},e)}))))})))})))):r.a.createElement(k.a,{text:"dark"},r.a.createElement(k.a.Header,null,r.a.createElement("h4",null,"Part-Of-Speech Tagging")),r.a.createElement(f.a,{variant:"flush"},n.map((function(e){return r.a.createElement(f.a.Item,{key:e},r.a.createElement("h5",null,e," :"),Object.keys(a[e]).map((function(t){return r.a.createElement(p.a,{key:t},r.a.createElement(d.a,{md:1},r.a.createElement(E.a,{variant:"dark",className:"m-1",disabled:!0},t,". ",r.a.createElement(r.a.Fragment,null),r.a.createElement(r.a.Fragment,null),r.a.createElement(g.a,null,a[e][t].length))),r.a.createElement(d.a,null,a[e][t].map((function(e,a){return r.a.createElement(E.a,{variant:"info",className:"m-1",key:a},r.a.createElement(h.a,{gap:1},r.a.createElement("div",null,e[0]),r.a.createElement(g.a,{className:"border",bg:"danger"},e[1])))}))))})))}))))},e}return Object(m.a)(t)}(s.a),v=Object(s.b)(b);c.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(v,null)),document.getElementById("root"))}},[[35,1,2]]]);
//# sourceMappingURL=main.92753d44.chunk.js.map